@@ -659,6 +659,8 @@ class Sf:
             ## [0,2] -> ['Web', 'Partner Reference']
             final_result_pd['validFor'] = final_result_pd.apply(lambda row: "\n".join([{v: k for k, v in row['controllerValues'].items()}[value] for value in row['validFor']]), axis=1)
             final_result_pd.drop(columns=['controllerValues'], inplace=True)
+            if final_result_pd['defaultValue'].isnull().all():
+                final_result_pd[['defaultValueLabel', 'defaultValueValue']] = np.nan
             final_result_pd[['defaultValueLabel', 'defaultValueValue']] = json_normalize(final_result_pd['defaultValue'])[['label','value']]
             final_result_pd.drop(columns=['defaultValue'], inplace=True)
             final_result_pd = pd.merge(final_result_pd, controlling_fields, left_on='Field_API', right_on='Field', how='left').drop(columns=['Field']).copy()
